@@ -132,8 +132,8 @@ resource_buildDatabase (
                         Display *display,
                         char *app_class,
                         char *app_name,
-                        int *argcP,
-                        char **argv)
+                        int *argcP _GL_UNUSED,
+                        char **argv _GL_UNUSED)
 {
   XrmDatabase gvdb = XtDatabase(display);
   XrmDatabase db = NULL;
@@ -175,7 +175,7 @@ resource_buildDatabase (
   INFMESSAGE(checking for user resources)
 
   strcpy(tmp,USER_DEFAULTS);
-  file_translateTildeInPath(tmp);
+  file_translateTildeInPath(tmp, sizeof(tmp));
   if (!file_fileIsNotUseful(tmp)) {
     s = XtNewString(tmp);
     tildeGv = USER_DEFAULTS;
@@ -254,7 +254,7 @@ resource_buildDatabase (
      
      strcpy(tmp,USER_DEFAULTS "-");
      strcat(tmp, locale1);
-     file_translateTildeInPath(tmp);
+     file_translateTildeInPath(tmp, sizeof(tmp));
      if (!stat(tmp, &buf))
      {
         i18n = 1;
@@ -304,7 +304,7 @@ resource_buildDatabase (
      
      strcpy(tmp,USER_DEFAULTS "-");
      strcat(tmp, locale2);
-     file_translateTildeInPath(tmp);
+     file_translateTildeInPath(tmp, sizeof(tmp));
      if (!stat(tmp, &buf))
      {
         i18n = 1;
@@ -349,7 +349,7 @@ resource_buildDatabase (
      
      strcpy(tmp,USER_DEFAULTS "-");
      strcat(tmp, locale3);
-     file_translateTildeInPath(tmp);
+     file_translateTildeInPath(tmp, sizeof(tmp));
      if (!stat(tmp, &buf))
      {
         i18n = 1;
@@ -865,7 +865,6 @@ static char* resource_mergeFileIntoDatabase(dbP,name)
      char *name;
 {
   char tmp[GV_MAX_FILENAME_LENGTH];
-  int useful=0;
 
   BEGINMESSAGE(resource_mergeFileIntoDatabase)
 
@@ -875,38 +874,20 @@ static char* resource_mergeFileIntoDatabase(dbP,name)
     }
 
   strcpy(tmp,name);
-  file_translateTildeInPath(tmp);
+  file_translateTildeInPath(tmp, sizeof(tmp));
 
-  if (file_fileIsNotUseful(tmp)) {
+  if (tmp[0] != '/') {
+    fprintf(stderr, "Ignoring resource file '%s'='%s' as no absolute path!\n",
+		    name, tmp);
+    name = NULL;
+  } else if (file_fileIsNotUseful(tmp)) {
     INFSMESSAGE(not useful,tmp)
-      if (name != file_locateFilename(name)) useful=-1;
-      else {
-
-	sprintf(tmp,"~/%s",name);
-	file_translateTildeInPath(tmp);
-
-      }
-  } else useful=1;
-
-  if (!useful) {
-
-    if (!useful && file_fileIsNotUseful(tmp)) {
-      INFSMESSAGE(not useful,tmp)
-	sprintf(tmp,"%s%s",GV_LIBDIR,name);
-    } else useful=1;
-
-    if (!useful && file_fileIsNotUseful(tmp)) {
-      INFSMESSAGE(not useful,tmp)
-	INFMESSAGE(giving up)
-	} else useful=1;
-  }
-
-  if (useful==1) {
+    name = NULL;
+  } else {
     INFSMESSAGE(merging,tmp)
       XrmCombineFileDatabase(tmp,dbP,True);
     name = XtNewString(tmp);
   }
-  else name=NULL;
   ENDMESSAGE(resource_mergeFileIntoDatabase)
     return(name);
 }
